@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: chunked-data
 version: 0.2.0
-id: chunked-data-0.2.0-b92c1c54ff991377166d1c34a28deffa
-key: chunk_4A1X9LfY5V55deyREe5tMP
+id: chunked-data-0.2.0-a32ff507f486d0cf08dd0f1ae2d814dc
+key: chunk_KCk33Zh2JPfLRB95GYyE4P
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/fpco/chunked-data
@@ -20,14 +20,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/chunked-data-0.2.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/chunked-data-0.2.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/chunked-data-0.2.0
-hs-libraries: HSchunked-data-0.2.0-4A1X9LfY5V55deyREe5tMP
+hs-libraries: HSchunked-data-0.2.0-KCk33Zh2JPfLRB95GYyE4P
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    mono-traversable-0.10.2-6786ce4edfbddf2ce2aafd4eb9614140
-    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
+    mono-traversable-0.10.2-183dbee45ad80b580fee3545c451925a
+    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
